# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: uuid.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nuuid.proto\x12\x11opi_api.common.v1\"\x15\n\x04Uuid\x12\r\n\x05value\x18\x01 \x01(\tBP\n\x11opi_api.common.v1B\tUuidProtoP\x01Z.github.com/opiproject/opi-api/common/v1/gen/gob\x06proto3')



_UUID = DESCRIPTOR.message_types_by_name['Uuid']
Uuid = _reflection.GeneratedProtocolMessageType('Uuid', (_message.Message,), {
  'DESCRIPTOR' : _UUID,
  '__module__' : 'uuid_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.common.v1.Uuid)
  })
_sym_db.RegisterMessage(Uuid)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\021opi_api.common.v1B\tUuidProtoP\001Z.github.com/opiproject/opi-api/common/v1/gen/go'
  _UUID._serialized_start=33
  _UUID._serialized_end=54
# @@protoc_insertion_point(module_scope)
