# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: frontend_nvme_pcie.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import opicommon_pb2 as opicommon__pb2
import object_key_pb2 as object__key__pb2
import uuid_pb2 as uuid__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x66rontend_nvme_pcie.proto\x12\x12opi_api.storage.v1\x1a\x0fopicommon.proto\x1a\x10object_key.proto\x1a\nuuid.proto\x1a\x17google/api/client.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a google/protobuf/field_mask.proto\"}\n\rNVMeSubsystem\x12\x33\n\x04spec\x18\x01 \x01(\x0b\x32%.opi_api.storage.v1.NVMeSubsystemSpec\x12\x37\n\x06status\x18\x02 \x01(\x0b\x32\'.opi_api.storage.v1.NVMeSubsystemStatus\"\x8f\x01\n\x11NVMeSubsystemSpec\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12\x0b\n\x03nqn\x18\x02 \x01(\t\x12\x15\n\rserial_number\x18\x03 \x01(\t\x12\x14\n\x0cmodel_number\x18\x04 \x01(\t\x12\x16\n\x0emax_namespaces\x18\x05 \x01(\x03\"B\n\x13NVMeSubsystemStatus\x12\x19\n\x11\x66irmware_revision\x18\x01 \x01(\t\x12\x10\n\x08\x66ru_guid\x18\x02 \x01(\x0c\"\x80\x01\n\x0eNVMeController\x12\x34\n\x04spec\x18\x01 \x01(\x0b\x32&.opi_api.storage.v1.NVMeControllerSpec\x12\x38\n\x06status\x18\x02 \x01(\x0b\x32(.opi_api.storage.v1.NVMeControllerStatus\"\x96\x02\n\x12NVMeControllerSpec\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12\x1a\n\x12nvme_controller_id\x18\x02 \x01(\x05\x12\x32\n\x0csubsystem_id\x18\x03 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12\x30\n\x07pcie_id\x18\x04 \x01(\x0b\x32\x1f.opi_api.storage.v1.PciEndpoint\x12\x0f\n\x07max_nsq\x18\x05 \x01(\x05\x12\x0f\n\x07max_ncq\x18\x06 \x01(\x05\x12\x0c\n\x04sqes\x18\x07 \x01(\x05\x12\x0c\n\x04\x63qes\x18\x08 \x01(\x05\x12\x16\n\x0emax_namespaces\x18\t \x01(\x05\"&\n\x14NVMeControllerStatus\x12\x0e\n\x06\x61\x63tive\x18\x01 \x01(\x08\"}\n\rNVMeNamespace\x12\x33\n\x04spec\x18\x01 \x01(\x0b\x32%.opi_api.storage.v1.NVMeNamespaceSpec\x12\x37\n\x06status\x18\x02 \x01(\x0b\x32\'.opi_api.storage.v1.NVMeNamespaceStatus\"\xfa\x01\n\x11NVMeNamespaceSpec\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12\x32\n\x0csubsystem_id\x18\x02 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12\x11\n\thost_nsid\x18\x04 \x01(\x05\x12\r\n\x05nguid\x18\x07 \x01(\t\x12\r\n\x05\x65ui64\x18\x08 \x01(\x03\x12%\n\x04uuid\x18\t \x01(\x0b\x32\x17.opi_api.common.v1.Uuid\x12/\n\tvolume_id\x18\n \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\"\x9a\x01\n\x13NVMeNamespaceStatus\x12<\n\tpci_state\x18\x01 \x01(\x0e\x32).opi_api.storage.v1.NVMeNamespacePciState\x12\x45\n\x0epci_oper_state\x18\x02 \x01(\x0e\x32-.opi_api.storage.v1.NVMeNamespacePciOperState\"\xb3\x01\n\x1a\x43reateNVMeSubsystemRequest\x12\x38\n\x06parent\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41\"\n opi_api.storage.v1/NVMeSubsystem\x12?\n\x0fnv_me_subsystem\x18\x02 \x01(\x0b\x32!.opi_api.storage.v1.NVMeSubsystemB\x03\xe0\x41\x02\x12\x1a\n\x12nv_me_subsystem_id\x18\x03 \x01(\t\"T\n\x1a\x44\x65leteNVMeSubsystemRequest\x12\x36\n\x04name\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41\"\n opi_api.storage.v1/NVMeSubsystem\"\x89\x01\n\x1aUpdateNVMeSubsystemRequest\x12:\n\x0fnv_me_subsystem\x18\x01 \x01(\x0b\x32!.opi_api.storage.v1.NVMeSubsystem\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"|\n\x19ListNVMeSubsystemsRequest\x12\x38\n\x06parent\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41\"\n opi_api.storage.v1/NVMeSubsystem\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"r\n\x1aListNVMeSubsystemsResponse\x12;\n\x10nv_me_subsystems\x18\x01 \x03(\x0b\x32!.opi_api.storage.v1.NVMeSubsystem\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"Q\n\x17GetNVMeSubsystemRequest\x12\x36\n\x04name\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41\"\n opi_api.storage.v1/NVMeSubsystem\"O\n\x19NVMeSubsystemStatsRequest\x12\x32\n\x0csubsystem_id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\"L\n\x1aNVMeSubsystemStatsResponse\x12.\n\x05stats\x18\x01 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStats\"\xb8\x01\n\x1b\x43reateNVMeControllerRequest\x12\x39\n\x06parent\x18\x01 \x01(\tB)\xe0\x41\x02\xfa\x41#\n!opi_api.storage.v1/NVMeController\x12\x41\n\x10nv_me_controller\x18\x02 \x01(\x0b\x32\".opi_api.storage.v1.NVMeControllerB\x03\xe0\x41\x02\x12\x1b\n\x13nv_me_controller_id\x18\x03 \x01(\t\"V\n\x1b\x44\x65leteNVMeControllerRequest\x12\x37\n\x04name\x18\x01 \x01(\tB)\xe0\x41\x02\xfa\x41#\n!opi_api.storage.v1/NVMeController\"\x8c\x01\n\x1bUpdateNVMeControllerRequest\x12<\n\x10nv_me_controller\x18\x01 \x01(\x0b\x32\".opi_api.storage.v1.NVMeController\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"~\n\x1aListNVMeControllersRequest\x12\x39\n\x06parent\x18\x01 \x01(\tB)\xe0\x41\x02\xfa\x41#\n!opi_api.storage.v1/NVMeController\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"u\n\x1bListNVMeControllersResponse\x12=\n\x11nv_me_controllers\x18\x01 \x03(\x0b\x32\".opi_api.storage.v1.NVMeController\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"S\n\x18GetNVMeControllerRequest\x12\x37\n\x04name\x18\x01 \x01(\tB)\xe0\x41\x02\xfa\x41#\n!opi_api.storage.v1/NVMeController\"F\n\x1aNVMeControllerStatsRequest\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\"w\n\x1bNVMeControllerStatsResponse\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12.\n\x05stats\x18\x02 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStats\"\xb3\x01\n\x1a\x43reateNVMeNamespaceRequest\x12\x38\n\x06parent\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41\"\n opi_api.storage.v1/NVMeNamespace\x12?\n\x0fnv_me_namespace\x18\x02 \x01(\x0b\x32!.opi_api.storage.v1.NVMeNamespaceB\x03\xe0\x41\x02\x12\x1a\n\x12nv_me_namespace_id\x18\x03 \x01(\t\"T\n\x1a\x44\x65leteNVMeNamespaceRequest\x12\x36\n\x04name\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41\"\n opi_api.storage.v1/NVMeNamespace\"\x89\x01\n\x1aUpdateNVMeNamespaceRequest\x12:\n\x0fnv_me_namespace\x18\x01 \x01(\x0b\x32!.opi_api.storage.v1.NVMeNamespace\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"|\n\x19ListNVMeNamespacesRequest\x12\x38\n\x06parent\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41\"\n opi_api.storage.v1/NVMeNamespace\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"r\n\x1aListNVMeNamespacesResponse\x12;\n\x10nv_me_namespaces\x18\x01 \x03(\x0b\x32!.opi_api.storage.v1.NVMeNamespace\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"Q\n\x17GetNVMeNamespaceRequest\x12\x36\n\x04name\x18\x01 \x01(\tB(\xe0\x41\x02\xfa\x41\"\n opi_api.storage.v1/NVMeNamespace\"O\n\x19NVMeNamespaceStatsRequest\x12\x32\n\x0cnamespace_id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\"v\n\x1aNVMeNamespaceStatsResponse\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.opi_api.common.v1.ObjectKey\x12.\n\x05stats\x18\x02 \x01(\x0b\x32\x1f.opi_api.storage.v1.VolumeStats*\xb6\x01\n\x15NVMeNamespacePciState\x12)\n%NV_ME_NAMESPACE_PCI_STATE_UNSPECIFIED\x10\x00\x12%\n!NVME_NAMESPACE_PCI_STATE_DISABLED\x10\x01\x12$\n NVME_NAMESPACE_PCI_STATE_ENABLED\x10\x02\x12%\n!NVME_NAMESPACE_PCI_STATE_DELETING\x10\x03*\xa0\x01\n\x19NVMeNamespacePciOperState\x12.\n*NV_ME_NAMESPACE_PCI_OPER_STATE_UNSPECIFIED\x10\x00\x12(\n$NVME_NAMESPACE_PCI_OPER_STATE_ONLINE\x10\x01\x12)\n%NVME_NAMESPACE_PCI_OPER_STATE_OFFLINE\x10\x02\x32\xa5\x17\n\x13\x46rontendNvmeService\x12\xc6\x01\n\x13\x43reateNVMeSubsystem\x12..opi_api.storage.v1.CreateNVMeSubsystemRequest\x1a!.opi_api.storage.v1.NVMeSubsystem\"\\\x82\xd3\xe4\x93\x02*\"\x17/v1/{parent=subsystems}:\x0fnv_me_subsystem\xda\x41)parent,nv_me_subsystem,nv_me_subsystem_id\x12\x8f\x01\n\x13\x44\x65leteNVMeSubsystem\x12..opi_api.storage.v1.DeleteNVMeSubsystemRequest\x1a\x16.google.protobuf.Empty\"0\x82\xd3\xe4\x93\x02#*!/v1/{name=subsystems}/{subsystem}\xda\x41\x04name\x12\xc6\x01\n\x13UpdateNVMeSubsystem\x12..opi_api.storage.v1.UpdateNVMeSubsystemRequest\x1a!.opi_api.storage.v1.NVMeSubsystem\"\\\x82\xd3\xe4\x93\x02\x38\x32%/v1/{nv_me_subsystem.name=subsystems}:\x0fnv_me_subsystem\xda\x41\x1bnv_me_subsystem,update_mask\x12\x9d\x01\n\x12ListNVMeSubsystems\x12-.opi_api.storage.v1.ListNVMeSubsystemsRequest\x1a..opi_api.storage.v1.ListNVMeSubsystemsResponse\"(\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/{parent=subsystems}\xda\x41\x06parent\x12\x94\x01\n\x10GetNVMeSubsystem\x12+.opi_api.storage.v1.GetNVMeSubsystemRequest\x1a!.opi_api.storage.v1.NVMeSubsystem\"0\x82\xd3\xe4\x93\x02#\x12!/v1/{name=subsystems}/{subsystem}\xda\x41\x04name\x12u\n\x12NVMeSubsystemStats\x12-.opi_api.storage.v1.NVMeSubsystemStatsRequest\x1a..opi_api.storage.v1.NVMeSubsystemStatsResponse\"\x00\x12\xcc\x01\n\x14\x43reateNVMeController\x12/.opi_api.storage.v1.CreateNVMeControllerRequest\x1a\".opi_api.storage.v1.NVMeController\"_\x82\xd3\xe4\x93\x02+\"\x17/v1/{parent=subsystems}:\x10nv_me_controller\xda\x41+parent,nv_me_controller,nv_me_controller_id\x12\x93\x01\n\x14\x44\x65leteNVMeController\x12/.opi_api.storage.v1.DeleteNVMeControllerRequest\x1a\x16.google.protobuf.Empty\"2\x82\xd3\xe4\x93\x02%*#/v1/{name=controllers}/{controller}\xda\x41\x04name\x12\xcc\x01\n\x14UpdateNVMeController\x12/.opi_api.storage.v1.UpdateNVMeControllerRequest\x1a\".opi_api.storage.v1.NVMeController\"_\x82\xd3\xe4\x93\x02:2&/v1/{nv_me_controller.name=subsystems}:\x10nv_me_controller\xda\x41\x1cnv_me_controller,update_mask\x12\xa0\x01\n\x13ListNVMeControllers\x12..opi_api.storage.v1.ListNVMeControllersRequest\x1a/.opi_api.storage.v1.ListNVMeControllersResponse\"(\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/{parent=subsystems}\xda\x41\x06parent\x12\x98\x01\n\x11GetNVMeController\x12,.opi_api.storage.v1.GetNVMeControllerRequest\x1a\".opi_api.storage.v1.NVMeController\"1\x82\xd3\xe4\x93\x02$\x12\"/v1/{name=subsystems}/{controller}\xda\x41\x04name\x12x\n\x13NVMeControllerStats\x12..opi_api.storage.v1.NVMeControllerStatsRequest\x1a/.opi_api.storage.v1.NVMeControllerStatsResponse\"\x00\x12\xc6\x01\n\x13\x43reateNVMeNamespace\x12..opi_api.storage.v1.CreateNVMeNamespaceRequest\x1a!.opi_api.storage.v1.NVMeNamespace\"\\\x82\xd3\xe4\x93\x02*\"\x17/v1/{parent=subsystems}:\x0fnv_me_namespace\xda\x41)parent,nv_me_namespace,nv_me_namespace_id\x12\x8f\x01\n\x13\x44\x65leteNVMeNamespace\x12..opi_api.storage.v1.DeleteNVMeNamespaceRequest\x1a\x16.google.protobuf.Empty\"0\x82\xd3\xe4\x93\x02#*!/v1/{name=namespaces}/{namespace}\xda\x41\x04name\x12\xc6\x01\n\x13UpdateNVMeNamespace\x12..opi_api.storage.v1.UpdateNVMeNamespaceRequest\x1a!.opi_api.storage.v1.NVMeNamespace\"\\\x82\xd3\xe4\x93\x02\x38\x32%/v1/{nv_me_namespace.name=subsystems}:\x0fnv_me_namespace\xda\x41\x1bnv_me_namespace,update_mask\x12\x9d\x01\n\x12ListNVMeNamespaces\x12-.opi_api.storage.v1.ListNVMeNamespacesRequest\x1a..opi_api.storage.v1.ListNVMeNamespacesResponse\"(\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/{parent=subsystems}\xda\x41\x06parent\x12\x94\x01\n\x10GetNVMeNamespace\x12+.opi_api.storage.v1.GetNVMeNamespaceRequest\x1a!.opi_api.storage.v1.NVMeNamespace\"0\x82\xd3\xe4\x93\x02#\x12!/v1/{name=subsystems}/{namespace}\xda\x41\x04name\x12u\n\x12NVMeNamespaceStats\x12-.opi_api.storage.v1.NVMeNamespaceStatsRequest\x1a..opi_api.storage.v1.NVMeNamespaceStatsResponse\"\x00\x42\x64\n\x12opi_api.storage.v1B\x15\x46rontendNvmePcieProtoP\x01Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/gob\x06proto3')

_NVMENAMESPACEPCISTATE = DESCRIPTOR.enum_types_by_name['NVMeNamespacePciState']
NVMeNamespacePciState = enum_type_wrapper.EnumTypeWrapper(_NVMENAMESPACEPCISTATE)
_NVMENAMESPACEPCIOPERSTATE = DESCRIPTOR.enum_types_by_name['NVMeNamespacePciOperState']
NVMeNamespacePciOperState = enum_type_wrapper.EnumTypeWrapper(_NVMENAMESPACEPCIOPERSTATE)
NV_ME_NAMESPACE_PCI_STATE_UNSPECIFIED = 0
NVME_NAMESPACE_PCI_STATE_DISABLED = 1
NVME_NAMESPACE_PCI_STATE_ENABLED = 2
NVME_NAMESPACE_PCI_STATE_DELETING = 3
NV_ME_NAMESPACE_PCI_OPER_STATE_UNSPECIFIED = 0
NVME_NAMESPACE_PCI_OPER_STATE_ONLINE = 1
NVME_NAMESPACE_PCI_OPER_STATE_OFFLINE = 2


_NVMESUBSYSTEM = DESCRIPTOR.message_types_by_name['NVMeSubsystem']
_NVMESUBSYSTEMSPEC = DESCRIPTOR.message_types_by_name['NVMeSubsystemSpec']
_NVMESUBSYSTEMSTATUS = DESCRIPTOR.message_types_by_name['NVMeSubsystemStatus']
_NVMECONTROLLER = DESCRIPTOR.message_types_by_name['NVMeController']
_NVMECONTROLLERSPEC = DESCRIPTOR.message_types_by_name['NVMeControllerSpec']
_NVMECONTROLLERSTATUS = DESCRIPTOR.message_types_by_name['NVMeControllerStatus']
_NVMENAMESPACE = DESCRIPTOR.message_types_by_name['NVMeNamespace']
_NVMENAMESPACESPEC = DESCRIPTOR.message_types_by_name['NVMeNamespaceSpec']
_NVMENAMESPACESTATUS = DESCRIPTOR.message_types_by_name['NVMeNamespaceStatus']
_CREATENVMESUBSYSTEMREQUEST = DESCRIPTOR.message_types_by_name['CreateNVMeSubsystemRequest']
_DELETENVMESUBSYSTEMREQUEST = DESCRIPTOR.message_types_by_name['DeleteNVMeSubsystemRequest']
_UPDATENVMESUBSYSTEMREQUEST = DESCRIPTOR.message_types_by_name['UpdateNVMeSubsystemRequest']
_LISTNVMESUBSYSTEMSREQUEST = DESCRIPTOR.message_types_by_name['ListNVMeSubsystemsRequest']
_LISTNVMESUBSYSTEMSRESPONSE = DESCRIPTOR.message_types_by_name['ListNVMeSubsystemsResponse']
_GETNVMESUBSYSTEMREQUEST = DESCRIPTOR.message_types_by_name['GetNVMeSubsystemRequest']
_NVMESUBSYSTEMSTATSREQUEST = DESCRIPTOR.message_types_by_name['NVMeSubsystemStatsRequest']
_NVMESUBSYSTEMSTATSRESPONSE = DESCRIPTOR.message_types_by_name['NVMeSubsystemStatsResponse']
_CREATENVMECONTROLLERREQUEST = DESCRIPTOR.message_types_by_name['CreateNVMeControllerRequest']
_DELETENVMECONTROLLERREQUEST = DESCRIPTOR.message_types_by_name['DeleteNVMeControllerRequest']
_UPDATENVMECONTROLLERREQUEST = DESCRIPTOR.message_types_by_name['UpdateNVMeControllerRequest']
_LISTNVMECONTROLLERSREQUEST = DESCRIPTOR.message_types_by_name['ListNVMeControllersRequest']
_LISTNVMECONTROLLERSRESPONSE = DESCRIPTOR.message_types_by_name['ListNVMeControllersResponse']
_GETNVMECONTROLLERREQUEST = DESCRIPTOR.message_types_by_name['GetNVMeControllerRequest']
_NVMECONTROLLERSTATSREQUEST = DESCRIPTOR.message_types_by_name['NVMeControllerStatsRequest']
_NVMECONTROLLERSTATSRESPONSE = DESCRIPTOR.message_types_by_name['NVMeControllerStatsResponse']
_CREATENVMENAMESPACEREQUEST = DESCRIPTOR.message_types_by_name['CreateNVMeNamespaceRequest']
_DELETENVMENAMESPACEREQUEST = DESCRIPTOR.message_types_by_name['DeleteNVMeNamespaceRequest']
_UPDATENVMENAMESPACEREQUEST = DESCRIPTOR.message_types_by_name['UpdateNVMeNamespaceRequest']
_LISTNVMENAMESPACESREQUEST = DESCRIPTOR.message_types_by_name['ListNVMeNamespacesRequest']
_LISTNVMENAMESPACESRESPONSE = DESCRIPTOR.message_types_by_name['ListNVMeNamespacesResponse']
_GETNVMENAMESPACEREQUEST = DESCRIPTOR.message_types_by_name['GetNVMeNamespaceRequest']
_NVMENAMESPACESTATSREQUEST = DESCRIPTOR.message_types_by_name['NVMeNamespaceStatsRequest']
_NVMENAMESPACESTATSRESPONSE = DESCRIPTOR.message_types_by_name['NVMeNamespaceStatsResponse']
NVMeSubsystem = _reflection.GeneratedProtocolMessageType('NVMeSubsystem', (_message.Message,), {
  'DESCRIPTOR' : _NVMESUBSYSTEM,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeSubsystem)
  })
_sym_db.RegisterMessage(NVMeSubsystem)

NVMeSubsystemSpec = _reflection.GeneratedProtocolMessageType('NVMeSubsystemSpec', (_message.Message,), {
  'DESCRIPTOR' : _NVMESUBSYSTEMSPEC,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeSubsystemSpec)
  })
_sym_db.RegisterMessage(NVMeSubsystemSpec)

NVMeSubsystemStatus = _reflection.GeneratedProtocolMessageType('NVMeSubsystemStatus', (_message.Message,), {
  'DESCRIPTOR' : _NVMESUBSYSTEMSTATUS,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeSubsystemStatus)
  })
_sym_db.RegisterMessage(NVMeSubsystemStatus)

NVMeController = _reflection.GeneratedProtocolMessageType('NVMeController', (_message.Message,), {
  'DESCRIPTOR' : _NVMECONTROLLER,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeController)
  })
_sym_db.RegisterMessage(NVMeController)

NVMeControllerSpec = _reflection.GeneratedProtocolMessageType('NVMeControllerSpec', (_message.Message,), {
  'DESCRIPTOR' : _NVMECONTROLLERSPEC,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeControllerSpec)
  })
_sym_db.RegisterMessage(NVMeControllerSpec)

NVMeControllerStatus = _reflection.GeneratedProtocolMessageType('NVMeControllerStatus', (_message.Message,), {
  'DESCRIPTOR' : _NVMECONTROLLERSTATUS,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeControllerStatus)
  })
_sym_db.RegisterMessage(NVMeControllerStatus)

NVMeNamespace = _reflection.GeneratedProtocolMessageType('NVMeNamespace', (_message.Message,), {
  'DESCRIPTOR' : _NVMENAMESPACE,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeNamespace)
  })
_sym_db.RegisterMessage(NVMeNamespace)

NVMeNamespaceSpec = _reflection.GeneratedProtocolMessageType('NVMeNamespaceSpec', (_message.Message,), {
  'DESCRIPTOR' : _NVMENAMESPACESPEC,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeNamespaceSpec)
  })
_sym_db.RegisterMessage(NVMeNamespaceSpec)

NVMeNamespaceStatus = _reflection.GeneratedProtocolMessageType('NVMeNamespaceStatus', (_message.Message,), {
  'DESCRIPTOR' : _NVMENAMESPACESTATUS,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeNamespaceStatus)
  })
_sym_db.RegisterMessage(NVMeNamespaceStatus)

CreateNVMeSubsystemRequest = _reflection.GeneratedProtocolMessageType('CreateNVMeSubsystemRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENVMESUBSYSTEMREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.CreateNVMeSubsystemRequest)
  })
_sym_db.RegisterMessage(CreateNVMeSubsystemRequest)

DeleteNVMeSubsystemRequest = _reflection.GeneratedProtocolMessageType('DeleteNVMeSubsystemRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETENVMESUBSYSTEMREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.DeleteNVMeSubsystemRequest)
  })
_sym_db.RegisterMessage(DeleteNVMeSubsystemRequest)

UpdateNVMeSubsystemRequest = _reflection.GeneratedProtocolMessageType('UpdateNVMeSubsystemRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENVMESUBSYSTEMREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.UpdateNVMeSubsystemRequest)
  })
_sym_db.RegisterMessage(UpdateNVMeSubsystemRequest)

ListNVMeSubsystemsRequest = _reflection.GeneratedProtocolMessageType('ListNVMeSubsystemsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTNVMESUBSYSTEMSREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.ListNVMeSubsystemsRequest)
  })
_sym_db.RegisterMessage(ListNVMeSubsystemsRequest)

ListNVMeSubsystemsResponse = _reflection.GeneratedProtocolMessageType('ListNVMeSubsystemsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNVMESUBSYSTEMSRESPONSE,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.ListNVMeSubsystemsResponse)
  })
_sym_db.RegisterMessage(ListNVMeSubsystemsResponse)

GetNVMeSubsystemRequest = _reflection.GeneratedProtocolMessageType('GetNVMeSubsystemRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNVMESUBSYSTEMREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.GetNVMeSubsystemRequest)
  })
_sym_db.RegisterMessage(GetNVMeSubsystemRequest)

NVMeSubsystemStatsRequest = _reflection.GeneratedProtocolMessageType('NVMeSubsystemStatsRequest', (_message.Message,), {
  'DESCRIPTOR' : _NVMESUBSYSTEMSTATSREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeSubsystemStatsRequest)
  })
_sym_db.RegisterMessage(NVMeSubsystemStatsRequest)

NVMeSubsystemStatsResponse = _reflection.GeneratedProtocolMessageType('NVMeSubsystemStatsResponse', (_message.Message,), {
  'DESCRIPTOR' : _NVMESUBSYSTEMSTATSRESPONSE,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeSubsystemStatsResponse)
  })
_sym_db.RegisterMessage(NVMeSubsystemStatsResponse)

CreateNVMeControllerRequest = _reflection.GeneratedProtocolMessageType('CreateNVMeControllerRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENVMECONTROLLERREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.CreateNVMeControllerRequest)
  })
_sym_db.RegisterMessage(CreateNVMeControllerRequest)

DeleteNVMeControllerRequest = _reflection.GeneratedProtocolMessageType('DeleteNVMeControllerRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETENVMECONTROLLERREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.DeleteNVMeControllerRequest)
  })
_sym_db.RegisterMessage(DeleteNVMeControllerRequest)

UpdateNVMeControllerRequest = _reflection.GeneratedProtocolMessageType('UpdateNVMeControllerRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENVMECONTROLLERREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.UpdateNVMeControllerRequest)
  })
_sym_db.RegisterMessage(UpdateNVMeControllerRequest)

ListNVMeControllersRequest = _reflection.GeneratedProtocolMessageType('ListNVMeControllersRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTNVMECONTROLLERSREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.ListNVMeControllersRequest)
  })
_sym_db.RegisterMessage(ListNVMeControllersRequest)

ListNVMeControllersResponse = _reflection.GeneratedProtocolMessageType('ListNVMeControllersResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNVMECONTROLLERSRESPONSE,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.ListNVMeControllersResponse)
  })
_sym_db.RegisterMessage(ListNVMeControllersResponse)

GetNVMeControllerRequest = _reflection.GeneratedProtocolMessageType('GetNVMeControllerRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNVMECONTROLLERREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.GetNVMeControllerRequest)
  })
_sym_db.RegisterMessage(GetNVMeControllerRequest)

NVMeControllerStatsRequest = _reflection.GeneratedProtocolMessageType('NVMeControllerStatsRequest', (_message.Message,), {
  'DESCRIPTOR' : _NVMECONTROLLERSTATSREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeControllerStatsRequest)
  })
_sym_db.RegisterMessage(NVMeControllerStatsRequest)

NVMeControllerStatsResponse = _reflection.GeneratedProtocolMessageType('NVMeControllerStatsResponse', (_message.Message,), {
  'DESCRIPTOR' : _NVMECONTROLLERSTATSRESPONSE,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeControllerStatsResponse)
  })
_sym_db.RegisterMessage(NVMeControllerStatsResponse)

CreateNVMeNamespaceRequest = _reflection.GeneratedProtocolMessageType('CreateNVMeNamespaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATENVMENAMESPACEREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.CreateNVMeNamespaceRequest)
  })
_sym_db.RegisterMessage(CreateNVMeNamespaceRequest)

DeleteNVMeNamespaceRequest = _reflection.GeneratedProtocolMessageType('DeleteNVMeNamespaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETENVMENAMESPACEREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.DeleteNVMeNamespaceRequest)
  })
_sym_db.RegisterMessage(DeleteNVMeNamespaceRequest)

UpdateNVMeNamespaceRequest = _reflection.GeneratedProtocolMessageType('UpdateNVMeNamespaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENVMENAMESPACEREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.UpdateNVMeNamespaceRequest)
  })
_sym_db.RegisterMessage(UpdateNVMeNamespaceRequest)

ListNVMeNamespacesRequest = _reflection.GeneratedProtocolMessageType('ListNVMeNamespacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTNVMENAMESPACESREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.ListNVMeNamespacesRequest)
  })
_sym_db.RegisterMessage(ListNVMeNamespacesRequest)

ListNVMeNamespacesResponse = _reflection.GeneratedProtocolMessageType('ListNVMeNamespacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTNVMENAMESPACESRESPONSE,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.ListNVMeNamespacesResponse)
  })
_sym_db.RegisterMessage(ListNVMeNamespacesResponse)

GetNVMeNamespaceRequest = _reflection.GeneratedProtocolMessageType('GetNVMeNamespaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETNVMENAMESPACEREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.GetNVMeNamespaceRequest)
  })
_sym_db.RegisterMessage(GetNVMeNamespaceRequest)

NVMeNamespaceStatsRequest = _reflection.GeneratedProtocolMessageType('NVMeNamespaceStatsRequest', (_message.Message,), {
  'DESCRIPTOR' : _NVMENAMESPACESTATSREQUEST,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeNamespaceStatsRequest)
  })
_sym_db.RegisterMessage(NVMeNamespaceStatsRequest)

NVMeNamespaceStatsResponse = _reflection.GeneratedProtocolMessageType('NVMeNamespaceStatsResponse', (_message.Message,), {
  'DESCRIPTOR' : _NVMENAMESPACESTATSRESPONSE,
  '__module__' : 'frontend_nvme_pcie_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.storage.v1.NVMeNamespaceStatsResponse)
  })
_sym_db.RegisterMessage(NVMeNamespaceStatsResponse)

_FRONTENDNVMESERVICE = DESCRIPTOR.services_by_name['FrontendNvmeService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\022opi_api.storage.v1B\025FrontendNvmePcieProtoP\001Z5github.com/opiproject/opi-api/storage/v1alpha1/gen/go'
  _CREATENVMESUBSYSTEMREQUEST.fields_by_name['parent']._options = None
  _CREATENVMESUBSYSTEMREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A\"\n opi_api.storage.v1/NVMeSubsystem'
  _CREATENVMESUBSYSTEMREQUEST.fields_by_name['nv_me_subsystem']._options = None
  _CREATENVMESUBSYSTEMREQUEST.fields_by_name['nv_me_subsystem']._serialized_options = b'\340A\002'
  _DELETENVMESUBSYSTEMREQUEST.fields_by_name['name']._options = None
  _DELETENVMESUBSYSTEMREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A\"\n opi_api.storage.v1/NVMeSubsystem'
  _LISTNVMESUBSYSTEMSREQUEST.fields_by_name['parent']._options = None
  _LISTNVMESUBSYSTEMSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A\"\n opi_api.storage.v1/NVMeSubsystem'
  _GETNVMESUBSYSTEMREQUEST.fields_by_name['name']._options = None
  _GETNVMESUBSYSTEMREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A\"\n opi_api.storage.v1/NVMeSubsystem'
  _CREATENVMECONTROLLERREQUEST.fields_by_name['parent']._options = None
  _CREATENVMECONTROLLERREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A#\n!opi_api.storage.v1/NVMeController'
  _CREATENVMECONTROLLERREQUEST.fields_by_name['nv_me_controller']._options = None
  _CREATENVMECONTROLLERREQUEST.fields_by_name['nv_me_controller']._serialized_options = b'\340A\002'
  _DELETENVMECONTROLLERREQUEST.fields_by_name['name']._options = None
  _DELETENVMECONTROLLERREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A#\n!opi_api.storage.v1/NVMeController'
  _LISTNVMECONTROLLERSREQUEST.fields_by_name['parent']._options = None
  _LISTNVMECONTROLLERSREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A#\n!opi_api.storage.v1/NVMeController'
  _GETNVMECONTROLLERREQUEST.fields_by_name['name']._options = None
  _GETNVMECONTROLLERREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A#\n!opi_api.storage.v1/NVMeController'
  _CREATENVMENAMESPACEREQUEST.fields_by_name['parent']._options = None
  _CREATENVMENAMESPACEREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A\"\n opi_api.storage.v1/NVMeNamespace'
  _CREATENVMENAMESPACEREQUEST.fields_by_name['nv_me_namespace']._options = None
  _CREATENVMENAMESPACEREQUEST.fields_by_name['nv_me_namespace']._serialized_options = b'\340A\002'
  _DELETENVMENAMESPACEREQUEST.fields_by_name['name']._options = None
  _DELETENVMENAMESPACEREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A\"\n opi_api.storage.v1/NVMeNamespace'
  _LISTNVMENAMESPACESREQUEST.fields_by_name['parent']._options = None
  _LISTNVMENAMESPACESREQUEST.fields_by_name['parent']._serialized_options = b'\340A\002\372A\"\n opi_api.storage.v1/NVMeNamespace'
  _GETNVMENAMESPACEREQUEST.fields_by_name['name']._options = None
  _GETNVMENAMESPACEREQUEST.fields_by_name['name']._serialized_options = b'\340A\002\372A\"\n opi_api.storage.v1/NVMeNamespace'
  _FRONTENDNVMESERVICE.methods_by_name['CreateNVMeSubsystem']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['CreateNVMeSubsystem']._serialized_options = b'\202\323\344\223\002*\"\027/v1/{parent=subsystems}:\017nv_me_subsystem\332A)parent,nv_me_subsystem,nv_me_subsystem_id'
  _FRONTENDNVMESERVICE.methods_by_name['DeleteNVMeSubsystem']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['DeleteNVMeSubsystem']._serialized_options = b'\202\323\344\223\002#*!/v1/{name=subsystems}/{subsystem}\332A\004name'
  _FRONTENDNVMESERVICE.methods_by_name['UpdateNVMeSubsystem']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['UpdateNVMeSubsystem']._serialized_options = b'\202\323\344\223\00282%/v1/{nv_me_subsystem.name=subsystems}:\017nv_me_subsystem\332A\033nv_me_subsystem,update_mask'
  _FRONTENDNVMESERVICE.methods_by_name['ListNVMeSubsystems']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['ListNVMeSubsystems']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/{parent=subsystems}\332A\006parent'
  _FRONTENDNVMESERVICE.methods_by_name['GetNVMeSubsystem']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['GetNVMeSubsystem']._serialized_options = b'\202\323\344\223\002#\022!/v1/{name=subsystems}/{subsystem}\332A\004name'
  _FRONTENDNVMESERVICE.methods_by_name['CreateNVMeController']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['CreateNVMeController']._serialized_options = b'\202\323\344\223\002+\"\027/v1/{parent=subsystems}:\020nv_me_controller\332A+parent,nv_me_controller,nv_me_controller_id'
  _FRONTENDNVMESERVICE.methods_by_name['DeleteNVMeController']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['DeleteNVMeController']._serialized_options = b'\202\323\344\223\002%*#/v1/{name=controllers}/{controller}\332A\004name'
  _FRONTENDNVMESERVICE.methods_by_name['UpdateNVMeController']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['UpdateNVMeController']._serialized_options = b'\202\323\344\223\002:2&/v1/{nv_me_controller.name=subsystems}:\020nv_me_controller\332A\034nv_me_controller,update_mask'
  _FRONTENDNVMESERVICE.methods_by_name['ListNVMeControllers']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['ListNVMeControllers']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/{parent=subsystems}\332A\006parent'
  _FRONTENDNVMESERVICE.methods_by_name['GetNVMeController']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['GetNVMeController']._serialized_options = b'\202\323\344\223\002$\022\"/v1/{name=subsystems}/{controller}\332A\004name'
  _FRONTENDNVMESERVICE.methods_by_name['CreateNVMeNamespace']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['CreateNVMeNamespace']._serialized_options = b'\202\323\344\223\002*\"\027/v1/{parent=subsystems}:\017nv_me_namespace\332A)parent,nv_me_namespace,nv_me_namespace_id'
  _FRONTENDNVMESERVICE.methods_by_name['DeleteNVMeNamespace']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['DeleteNVMeNamespace']._serialized_options = b'\202\323\344\223\002#*!/v1/{name=namespaces}/{namespace}\332A\004name'
  _FRONTENDNVMESERVICE.methods_by_name['UpdateNVMeNamespace']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['UpdateNVMeNamespace']._serialized_options = b'\202\323\344\223\00282%/v1/{nv_me_namespace.name=subsystems}:\017nv_me_namespace\332A\033nv_me_namespace,update_mask'
  _FRONTENDNVMESERVICE.methods_by_name['ListNVMeNamespaces']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['ListNVMeNamespaces']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/{parent=subsystems}\332A\006parent'
  _FRONTENDNVMESERVICE.methods_by_name['GetNVMeNamespace']._options = None
  _FRONTENDNVMESERVICE.methods_by_name['GetNVMeNamespace']._serialized_options = b'\202\323\344\223\002#\022!/v1/{name=subsystems}/{namespace}\332A\004name'
  _NVMENAMESPACEPCISTATE._serialized_start=4373
  _NVMENAMESPACEPCISTATE._serialized_end=4555
  _NVMENAMESPACEPCIOPERSTATE._serialized_start=4558
  _NVMENAMESPACEPCIOPERSTATE._serialized_end=4718
  _NVMESUBSYSTEM._serialized_start=273
  _NVMESUBSYSTEM._serialized_end=398
  _NVMESUBSYSTEMSPEC._serialized_start=401
  _NVMESUBSYSTEMSPEC._serialized_end=544
  _NVMESUBSYSTEMSTATUS._serialized_start=546
  _NVMESUBSYSTEMSTATUS._serialized_end=612
  _NVMECONTROLLER._serialized_start=615
  _NVMECONTROLLER._serialized_end=743
  _NVMECONTROLLERSPEC._serialized_start=746
  _NVMECONTROLLERSPEC._serialized_end=1024
  _NVMECONTROLLERSTATUS._serialized_start=1026
  _NVMECONTROLLERSTATUS._serialized_end=1064
  _NVMENAMESPACE._serialized_start=1066
  _NVMENAMESPACE._serialized_end=1191
  _NVMENAMESPACESPEC._serialized_start=1194
  _NVMENAMESPACESPEC._serialized_end=1444
  _NVMENAMESPACESTATUS._serialized_start=1447
  _NVMENAMESPACESTATUS._serialized_end=1601
  _CREATENVMESUBSYSTEMREQUEST._serialized_start=1604
  _CREATENVMESUBSYSTEMREQUEST._serialized_end=1783
  _DELETENVMESUBSYSTEMREQUEST._serialized_start=1785
  _DELETENVMESUBSYSTEMREQUEST._serialized_end=1869
  _UPDATENVMESUBSYSTEMREQUEST._serialized_start=1872
  _UPDATENVMESUBSYSTEMREQUEST._serialized_end=2009
  _LISTNVMESUBSYSTEMSREQUEST._serialized_start=2011
  _LISTNVMESUBSYSTEMSREQUEST._serialized_end=2135
  _LISTNVMESUBSYSTEMSRESPONSE._serialized_start=2137
  _LISTNVMESUBSYSTEMSRESPONSE._serialized_end=2251
  _GETNVMESUBSYSTEMREQUEST._serialized_start=2253
  _GETNVMESUBSYSTEMREQUEST._serialized_end=2334
  _NVMESUBSYSTEMSTATSREQUEST._serialized_start=2336
  _NVMESUBSYSTEMSTATSREQUEST._serialized_end=2415
  _NVMESUBSYSTEMSTATSRESPONSE._serialized_start=2417
  _NVMESUBSYSTEMSTATSRESPONSE._serialized_end=2493
  _CREATENVMECONTROLLERREQUEST._serialized_start=2496
  _CREATENVMECONTROLLERREQUEST._serialized_end=2680
  _DELETENVMECONTROLLERREQUEST._serialized_start=2682
  _DELETENVMECONTROLLERREQUEST._serialized_end=2768
  _UPDATENVMECONTROLLERREQUEST._serialized_start=2771
  _UPDATENVMECONTROLLERREQUEST._serialized_end=2911
  _LISTNVMECONTROLLERSREQUEST._serialized_start=2913
  _LISTNVMECONTROLLERSREQUEST._serialized_end=3039
  _LISTNVMECONTROLLERSRESPONSE._serialized_start=3041
  _LISTNVMECONTROLLERSRESPONSE._serialized_end=3158
  _GETNVMECONTROLLERREQUEST._serialized_start=3160
  _GETNVMECONTROLLERREQUEST._serialized_end=3243
  _NVMECONTROLLERSTATSREQUEST._serialized_start=3245
  _NVMECONTROLLERSTATSREQUEST._serialized_end=3315
  _NVMECONTROLLERSTATSRESPONSE._serialized_start=3317
  _NVMECONTROLLERSTATSRESPONSE._serialized_end=3436
  _CREATENVMENAMESPACEREQUEST._serialized_start=3439
  _CREATENVMENAMESPACEREQUEST._serialized_end=3618
  _DELETENVMENAMESPACEREQUEST._serialized_start=3620
  _DELETENVMENAMESPACEREQUEST._serialized_end=3704
  _UPDATENVMENAMESPACEREQUEST._serialized_start=3707
  _UPDATENVMENAMESPACEREQUEST._serialized_end=3844
  _LISTNVMENAMESPACESREQUEST._serialized_start=3846
  _LISTNVMENAMESPACESREQUEST._serialized_end=3970
  _LISTNVMENAMESPACESRESPONSE._serialized_start=3972
  _LISTNVMENAMESPACESRESPONSE._serialized_end=4086
  _GETNVMENAMESPACEREQUEST._serialized_start=4088
  _GETNVMENAMESPACEREQUEST._serialized_end=4169
  _NVMENAMESPACESTATSREQUEST._serialized_start=4171
  _NVMENAMESPACESTATSREQUEST._serialized_end=4250
  _NVMENAMESPACESTATSRESPONSE._serialized_start=4252
  _NVMENAMESPACESTATSRESPONSE._serialized_end=4370
  _FRONTENDNVMESERVICE._serialized_start=4721
  _FRONTENDNVMESERVICE._serialized_end=7702
# @@protoc_insertion_point(module_scope)
