# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: object_key.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10object_key.proto\x12\x11opi_api.common.v1\"\x1a\n\tObjectKey\x12\r\n\x05value\x18\x01 \x01(\tBU\n\x11opi_api.common.v1B\x0eObjectKeyProtoP\x01Z.github.com/opiproject/opi-api/common/v1/gen/gob\x06proto3')



_OBJECTKEY = DESCRIPTOR.message_types_by_name['ObjectKey']
ObjectKey = _reflection.GeneratedProtocolMessageType('ObjectKey', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTKEY,
  '__module__' : 'object_key_pb2'
  # @@protoc_insertion_point(class_scope:opi_api.common.v1.ObjectKey)
  })
_sym_db.RegisterMessage(ObjectKey)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\021opi_api.common.v1B\016ObjectKeyProtoP\001Z.github.com/opiproject/opi-api/common/v1/gen/go'
  _OBJECTKEY._serialized_start=39
  _OBJECTKEY._serialized_end=65
# @@protoc_insertion_point(module_scope)
